/*
 * Simulador.java
 *
 * Creado el 9 de mayo de 2006, 15:37
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mhpsc.sistema.ejemplo;

import java.awt.Color;
import java.awt.GridLayout;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import java.util.Timer;
import java.util.TimerTask;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.border.LineBorder;

/**
 *
 * @author avelino
 */
public class Simulador extends TimerTask implements KeyListener {
    private Estado estado;
    private Visualizador visualizador;
    private int counter;
    private Timer t;
    
    public Simulador(Estado estado) {
        this.estado = estado;
        this.estado.setMasa(40);
        this.estado.setFuerza(0);
        this.counter = 0;
        this.t = new Timer();
        this.visualizador = new Visualizador();
    }

    public void iniciar() {
        this.t.schedule(this, 0, Sistema.hMillis);
    }
    
    public void terminar() {
        this.t.cancel();
    }

    public void run() {
        Sistema.iterar(this.estado);
        this.visualizador.setPosicion(this.estado.getPosicion());
        //System.out.println("[" + this.counter + "] " + this.estado.toString());
        this.counter++;
    }
    
    public void setFuerza(float f) {
        this.estado.setFuerza(f);
    }
    
    public void setMasa(float m) {
        this.estado.setMasa(m);
    }
    
    public float getPosicion() {
        return this.estado.getPosicion();
    }
    
    public float getVelocidad() {
        return this.estado.getVelocidad();
    }

    public Visualizador getVisualizador() {
        return this.visualizador;
    }
    
    public void keyTyped(KeyEvent e) {
    }

    public void keyPressed(KeyEvent e) {
        if (e.getKeyCode() == e.VK_RIGHT)
            this.estado.setFuerza(500);
        else if (e.getKeyCode() == e.VK_LEFT)
            this.estado.setFuerza(-500);
        else if (e.getKeyCode() == e.VK_ESCAPE) {
            this.terminar();
            System.exit(0);
        }
    }

    public void keyReleased(KeyEvent e) {
        this.estado.setFuerza(0);
    }
    
    public static void main(String[] args) {
        Simulador s = new Simulador(new Estado());
        JFrame frame = new JFrame("Simulador de movimiento con rozamiento");
        frame.getContentPane().setLayout(new GridLayout(2, 1));
        frame.getContentPane().add(s.getVisualizador());
        frame.getContentPane().add(new JLabel("<html>Usar los cursores para mover la masa<br>ESC para salir</html>"));
        frame.setSize(400, 200);
        frame.addKeyListener(s);
        frame.show();
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        s.iniciar();
    }

}
