/*
 * Sistema.java
 *
 * Creado el 9 de mayo de 2006, 15:31
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mhpsc.sistema.ejemplo;

/**
 *
 * @author avelino
 */
public class Sistema {
    // intervalo de tiempo entre muestreos
    public static float h = (float)0.1;
    public static long hMillis = 100;
    // suponemos una foerza de rozamiento constante tanto esttica como dinmica
    public static float rozamiento = (float)0.5;
    
    public static void iterar(Estado estado) {
        float fuerzaAplicada = estado.getFuerza();
        // suponemos que la masa se encuentra en un plano horizontal y la normal es igual a su peso
        float fuerzaRozamiento = rozamiento * estado.getMasa() * (float)9.8;
        if (Math.abs(estado.getVelocidad()) < 1) {
            // en teora debera ser si estado.getVelocidad() == 0 pero esta condicin casinunca se da en instantes de tiempo discretos
            fuerzaRozamiento = 0;
            estado.setVelocidad(0);
        }
        else if (estado.getVelocidad() > 0) {
            // la fuerza de rozamiento siempre se opone al movimiento
            fuerzaRozamiento = -fuerzaRozamiento;
        }
        /*
         * Aplicamos la primera lew de Newton
         *
         *  dv
         * ---- = fuerzaResultante / masa
         *  dt
         *
         *  dp
         * ---- = v
         *  dt
         *
         * (v = velocidad, p = posicin) Para calcular la ecuacin diferencial utilizamos el metodo de euler:
         *
         *  dy
         * ---- = f(t, y)      <---->    y[i + 1] = y[i] + h * f(t[i], y[i])
         *  dt
         *
         * cuanto ms pequeo sea h mejor ser la aproximacin a la solucin
         */
        float fuerzaResultante = fuerzaAplicada + fuerzaRozamiento;
        float velocidadTemp = estado.getVelocidad() + (h * (fuerzaResultante / estado.getMasa()));
        float posicionTemp = estado.getPosicion() + (h * estado.getVelocidad());
        estado.setPosicion(posicionTemp);
        estado.setVelocidad(velocidadTemp);
    }
}
